/**
 * A PDF Destination object, representing a location and fitting strategy.
 * @memberof Core.Actions
 */
class Dest {
  /**
   * @param {?object} options - A map of properties to initialize on the Dest object
   * @property {number} page - Gets and sets the 1-based page number to go to.
   * @property {string} fit - Gets the fit style (One of XYZ, FitBH, FitH, FitBV, FitV, FitR, FitB, Fit)
   * @property {number|undefined} top - Gets the top of the destination rectangle
   * @property {number|undefined} left - Gets the left hand side of the destination rectangle
   * @property {number|undefined} bottom - Gets the bottom of the destination rectangle
   * @property {number|undefined} right - Gets the right hand side of the destination rectangle
   * @property {number|undefined} zoom - Gets the zoom at which to view the destination
   * @property {string|undefined} name - Gets the name of the destination
   */
  constructor(options) {
    this.page = options?.page || 1;
    this.fit = options?.fit || '';
    this.top = options?.top;
    this.left = options?.left;
    this.bottom = options?.bottom;
    this.right = options?.right;
    this.zoom = options?.zoom;
    this.name = options?.name;
  }
}

export default Dest;