import EventHandler from './EventHandler';

/**
 * Represents a full-featured control used for displaying a Document. The viewer supports text selection and text search, and several page view modes.
 * @memberof Core
 * @extends Core.EventHandler
 */
class DocumentViewer extends EventHandler {
  /**
   * Creates a new empty DocumentViewer.
   * @property {object} defaults - Default values for document viewer. Set FitMode, DisplayMode or Zoom.
   */
  constructor(defaults) {
    /**
     * Contains a list of available fit modes for the DocumentViewer.
     * @property {function} FitWidth - Zoom level is constrained such that the current page's width will exactly fill the available space.
     * @property {function} FitPage - Zoom level is constrained such that the current page's width or height will exactly fill the available space.
     * @property {function} Zoom - Zoom level is not constrained.
     */
    this.FitMode = null;
  }

  /**
   * @property {string} ACTIVE_SEARCH_RESULT_CHANGED - Core.DocumentViewer.activeSearchResultChanged
   * @property {string} MOUSE_LEFT_UP - Core.DocumentViewer.mouseLeftUp
   * @property {string} MOUSE_LEFT_DOWN - Core.DocumentViewer.mouseLeftDown
   * @property {string} CLICK - Core.DocumentViewer.click
   * @property {string} TAP - Core.DocumentViewer.tap
   * @property {string} LONG_TAP - Core.DocumentViewer.longTap
   * @property {string} DBL_CLICK - Core.DocumentViewer.dblClick
   * @property {string} KEY_DOWN - Core.DocumentViewer.keyDown
   * @property {string} KEY_UP - Core.DocumentViewer.keyUp
   * @property {string} MOUSE_ENTER - Core.DocumentViewer.mouseEnter
   * @property {string} MOUSE_MOVE - Core.DocumentViewer.mouseMove
   * @property {string} MOUSE_LEAVE - Core.DocumentViewer.mouseLeave
   * @property {string} MOUSE_RIGHT_DOWN - Core.DocumentViewer.mouseRightDown
   * @property {string} MOUSE_RIGHT_UP - Core.DocumentViewer.mouseRightUp
   * @property {string} DOCUMENT_UNLOADED - Core.DocumentViewer.documentUnloaded
   * @property {string} ANNOTATIONS_LOADED - Core.DocumentViewer.annotationsLoaded
   * @property {string} BEFORE_DOCUMENT_LOADED - Core.DocumentViewer.beforeDocumentLoaded
   * @property {string} DOCUMENT_LOADED - Core.DocumentViewer.documentLoaded
   * @property {string} DISPLAY_PAGE_LOCATION - Core.DocumentViewer.displayPageLocation
   * @property {string} NOTIFY - Core.DocumentViewer.notify
   * @property {string} SEARCH_IN_PROGRESS - Core.DocumentViewer.searchInProgress
   * @property {string} TEXT_SELECTED - Core.DocumentViewer.textSelected
   * @property {string} TOOL_MODE_UPDATED - Core.DocumentViewer.toolModeUpdated
   * @property {string} FIT_MODE_UPDATED - Core.DocumentViewer.fitModeUpdated
   * @property {string} ROTATION_UPDATED - Core.DocumentViewer.rotationUpdated
   * @property {string} ZOOM_UPDATED - Core.DocumentViewer.zoomUpdated
   * @property {string} PAGE_NUMBER_UPDATED - Core.DocumentViewer.pageNumberUpdated
   * @property {string} PAGES_UPDATED - Core.DocumentViewer.pagesUpdated
   * @property {string} PAGE_COMPLETE - Core.DocumentViewer.pageComplete
   * @property {string} DISPLAY_MODE_UPDATED - Core.DocumentViewer.displayModeUpdated
   * @property {string} BEGIN_RENDERING - Core.DocumentViewer.beginRendering
   * @property {string} FINISHED_RENDERING - Core.DocumentViewer.finishedRendering
   * @property {string} TOOL_UPDATED - Core.DocumentViewer.toolUpdated
   * @property {string} SNAP_MODE_INITIALIZED - Core.DocumentViewer.snapModeInitialized
   * @property {string} BEFORE_SNAP_MODE_INITIALIZED - Core.DocumentViewer.beforeSnapModeInitialized
   * @property {string} EMBEDDED_POP_UP_MENU - Core.DocumentViewer.embeddedPopUpMenu
   */
  static get Events() {}

  /** Clears all search results from the viewer */
  clearSearchResults() {}

  /** Clears any selected text on the all pages. */
  clearSelection() {}

  /**
   * Reinitializes data and clears the viewer area content.
   * @returns {Promise.<void>} A promise that resolves when the document is finished closing
   */
  closeDocument() {}

  /** Scrolls the viewer so that the upper-left corner of the Document's first page is in the upper-left corner of the viewer. */
  displayFirstPage() {}

  /** Scrolls the viewer so that the upper-left corner of the Document's last page is in the upper-left corner of the viewer. */
  displayLastPage() {}

  /**
   * Scrolls the viewer so that the position of the search result is in the middle of the viewer.
   * @param {object} result - The result of a search, Core.Search.SearchResult. Returned by onResult in Core.DocumentViewer#textSearchInit.
   * @param {function} [jump] - The callback for navigating to the found result. This is optional and will jump to the correct location in the DocumentViewer if no parameter is passed.
   */
  displaySearchResult(result, jump) {}

  /**
   * Returns the AnnotationHistoryManager used by this DocumentViewer
   * @returns {Core.AnnotationHistoryManager} An instance of AnnotationHistoryManager
   */
  getAnnotationHistoryManager() {}

  /**
   * Returns the AnnotationManager used by this DocumentViewer
   * @returns {Core.AnnotationManager} An instance of AnnotationManager
   */
  getAnnotationManager() {}

  /**
   * Returns the number of pages in a document.
   * @returns {number} The number of the pages in the current document.
   */
  getPageCount() {}

  /**
   * Get the width of a specified page in the document.
   * @param {number} pageNumber The page number to get the width of.
   * @return {number} The width of the page
   */
  getPageWidth(pageNumber) {}

  /**
   * Get the height of a specified page in the document.
   * @param {number} pageNumber The page number to get the height of.
   * @return {number} The height of the page
   */
  getPageHeight(pageNumber) {}

  /**
   * Returns the current tool.
   * @returns {Core.Tools.Tool} The current tool.
   */
  getToolMode() {}

  /**
   * Returns the current zoom level.
   * @returns {number} The current zoom level.
   */
  getZoomLevel() {}

  /**
   * Initialize the viewer and load the given file into the viewer.
   * @param {string | File | ArrayBuffer | Blob | Core.Document | Core.PDFNet.PDFDoc} src - Source parameter, path/url to document or File.
   * @param {Core.LoadDocumentOptions} [options] - Load document options.
   * @returns {Promise.<void>} A promise that resolves when the document is finished loading
   */
  loadDocument(src, options) {}

  /**
   * Selects the text content of the document given two page coordinates.
   * @param pt1 - Starting page coordinate. Requires properties x, y and pageNumber.
   * @param pt2 - Ending page coordinate. Requires properties x, y and pageNumber.
   */
  select(pt1, pt2) {}

  /**
   * Sets the current page. Updates the current page and jumps to it.
   * @param {number} pageNumber - The page number to jump to.
   * @param {boolean} isSmoothScroll - If set to true, the viewer will scroll in a smooth way.
   */
  setCurrentPage(pageNumber, isSmoothScroll) {}

  /**
   * Sets how the document will scale to fit the size of the scrollviewer's viewport. Also re-renders content to the appropriate zoom level. Only renders if a document has been loaded.
   * @param {function} fitMode - A fit mode property from Core.DocumentViewer#FitMode
   */
  setFitMode(fitMode) {}

  /**
   * Sets the tool mode. Also removes selection caused by text selection or search.
   * @param {Core.Tools.Tool} tool - An instance of the toolmode
   */
  setToolMode(tool) {}

  /**
   * Adjusts the viewer's zoom factor
   * @param {number} zoom - Zoom value.
   */
  zoomTo(zoom) {}



  /**
   * Download the document as an ArrayBuffer.
   * @return {Promise.<ArrayBuffer>}
   */
  download() {}

  /**
   * Switche the display mode of the web viewer.
   * @param {0|1|2} mode Display Mode Parameter, Single Mode: 0, Two-up Mode: 1, Cover Mode: 2
   */
  webViewerSwitchSpreadMode(mode) {}

  /** Request full screen mode for the web viewer. */
  requestFullScreenMode() {}
  
  /** Display the previous page in the web viewer. */
  previousPage() {}

  /** Display the next page in the web viewer. */
  nextPage() {}

  /**
   * Display the specified page in the web viewer.
   * @param {string} pageNumber The page number to display.
   */
  pageNumberChanged(pageNumber) {}

  /** Scroll the web viewer to the specified position. */
  scrollTo() {}

  /**
   * Switche the scroll mode of the web viewer.
   * @param {0|1} mode Scroll Mode Parameter, Vertical Mode: 0, Horizontal Mode: 1
   */
  webViewerSwitchScrollMode(mode) {}

  /**
   * Searche the document for the specified text.
   * @param {string} text The Searched Content.
   */
  search(text) {}

  /** Zoom in the web viewer. */
  zoomIn() {}

  /** Zoom out the web viewer. */
  zoomOut() {}

  /**
   * Change the scale of the web viewer.
   * @param {number} scale The scale to change to.
   */
  webViewerScaleChanged(scale) {}

  /**
   * Add annotations to the document.
   * @param {object} annotation The object containing the annotation to add.
   */
  addAnnotations(annotation) {}

  /**
   * Insert a blank page into the document.
   * @param {number} pageIndex The index to insert the blank page at.
   * @param {number} width The width of the blank page.
   * @param {number} height The height of the blank page.
   */
  insertBlankPage(pageIndex, width, height) {}

  /**
   * Insert pages into the document.
   * @param {File} file The file to insert.
   * @param {number} pageIndexToInsert The index to insert the pages at.
   * @param {Array.<number|string>} pagesIndexToInsert The index of the pages to insert.
   */
  insertPages(file, pageIndexToInsert, pagesIndexToInsert) {}

  /**
   * Remove pages from the document.
   * @param {Array.<number>} pagesIndexToDelete The index of the pages to remove.
   */
  removePages(pagesIndexToDelete) {}
  
  /**
   * Rotate pages in the document.
   * @param {Array.<number>} pagesIndexToRotate The index of the pages to rotate.
   * @param {number} rotation The rotation to apply to the pages.
   */
  rotatePages(pagesIndexToRotate, rotation) {}

  /**
   * Extract pages from the document.
   * @param {Array.<number|string>} pagesIndexToExtract The index of the pages to extract.
   * @return {Promise.<ArrayBuffer>} The ArrayBuffer of the extracted pages.
   */
  extractPages(pagesIndexToExtract) {}

  /**
   * Move pages in the document.
   * @param {string} pagesIndexToMove The index of the pages to move.
   * @param {number} targetPageIndex The index to move the pages to.
   */
  movePages(pagesIndexToMove, targetPageIndex) {}

  /**
   * Copy pages in the document.
   * @param {Array.<number>} pagesIndexToCopy The index of the pages to copy.
   */
  copyPages(pagesIndexToCopy) {}

  /**
   * Set the password for the document.
   * @param {string} password The password to set.
   */
  setPassword(password) {}

  /** Remove the password from the document. */
  removePassword() {}

  /**
   * Convert a point from page coordinates to window coordinates.
   * @param {object} pagePoint The point to convert.
   * @param {number} pagePoint.x The x coordinate of the point.
   * @param {number} pagePoint.y The y coordinate of the point.
   * @param {number} pageNumber The page number of the point.
   * @return {object} The converted point.
   */
  pageToWindow(pagePoint, pageNumber) {}

  /**
   * Convert a point from window coordinates to page coordinates.
   * @param {object} windowPoint The point to convert.
   * @param {number} windowPoint.x The x coordinate of the point.
   * @param {number} windowPoint.y The y coordinate of the point.
   * @param {number} pageNumber The page number of the point.
   * @return {object} The converted point.
   */
  windowToPage(windowPoint, pageNumber) {}

  /**
   * Get the scroll view element of the web viewer.
   * @return {HTMLElement} The scroll view element.
   */
  getScrollViewElement() {}

  /**
   * Get the selected page of the web viewer.
   * @param {object} windowCoordinates The window coordinates to convert.
   * @param {number} windowCoordinates.x The x coordinate of the point.
   * @param {number} windowCoordinates.y The y coordinate of the point.
   * @return {number} The selected page.
   */
  getSelectedPage(windowCoordinates) {}

  /**
   * Triggered when the active search result has changed
   * @param {object} result - The new active search result, Core.Search.SearchResult.
   * @event Core.DocumentViewer#activeSearchResultChanged
   */
  activeSearchResultChanged() {}

  /**
   * Triggered when a new document has been loaded
   * @event Core.DocumentViewer#documentLoaded
   */
  documentLoaded() {}

  /**
   * Triggered when all the annotations embedded in the document have been loaded
   * @event Core.DocumentViewer#annotationsLoaded
   */
  annotationsLoaded() {}

  /**
   * Triggered for the click event in the DocumentViewer's viewing area
   * @param {object} nativeEvt - Event object of the native JavaScript event
   * @event Core.DocumentViewer#click
   */
  click() {}

  /**
   * Triggered when the display mode is updated
   * @event Core.DocumentViewer#displayModeUpdated
   * @returns {Core.VirtualDisplayMode} The new display mode of the viewer
   */
  displayModeUpdated() {}

  /**
   * Triggered when a Widget is clicked that triggers the Embedded JavaScript popUpMenu API
   * @event Core.DocumentViewer#embeddedPopUpMenu
   * @param {Core.DocumentViewer.embeddedPopUpMenuData} popUpMenuData - Data provided from the Embedded JavaScript popUpMenu API being called
   */
  embeddedPopUpMenu() {}

  /**
   * Triggered when the current document has been closed and unloaded
   * @event Core.DocumentViewer#documentUnloaded
   */
  documentUnloaded() {}

  /**
   * Triggered when DocumentViewer finishes rendering pages
   * @event Core.DocumentViewer#finishedRendering
   */
  finishedRendering() {}

  /**
   * Triggered when the page number is updated
   * @event Core.DocumentViewer#pageNumberUpdated
   */
  pageNumberUpdated() {}

  /**
   * Triggered when the page number is updated
   * @event Core.DocumentViewer#zoomUpdated
   */
  zoomUpdated() {}
}
