/**
 * @memberof Core
 */
class EventHandler {
  /**
   * Add a handler to the given event name
   * @param {string|number} type - The name of the event to listen to
   * @param {function} fn - The handler to be called when the event is triggered
   * @param {object} [options] - Optional options object for addEventListener
   * @param {boolean} options.once - If true then the handler will be called only once
   * @returns {object} Returns the object that 'addEventListener' is being called on
   * @example
   * myObject.addEventListener('eventName', (eventParameter1, eventParameter2) => {
   *  ...
   * });
   */
  addEventListener(type, fn, options) {}

  /**
   * Remove a handler of the given event name and namespace (if given) or with a function reference
   * @param {string|number} [type] - The name of the event to remove the handler of with an optional namespace.
   * @param {function} [fn] - The handler associated with this event to be removed. If fn is undefined, all the handlers of the given event namespace will be removed. If you are not passing in this parameter then a namespace must be used with the event name.
   * @returns {object} Returns the object that 'removeEventListener' is being called on
   * @example
   * myObject.removeEventListener('eventName.namespace');
   * myObject.removeEventListener('eventName', fn);
   */
  removeEventListener(type, fn) {}

  /**
   * Calls the handlers of the event name with given data
   * @param {string|number} type - event name of which the handlers will be called.
   * @param {*} [data] - data that will be passed to the handlers. If data is an array, it will be spread and then passed to the handlers
   * @returns {object} Returns the object that 'trigger' is being called on
   * @example
   * myObject.trigger('eventName');
   * myObject.trigger('eventName', [eventParameter1, eventParameter2]);
   */
  trigger(type, data) {}
}